[![Documentation Status](https://readthedocs.org/projects/tftb/badge/?version=latest)](https://tftb.readthedocs.io/en/latest/?badge=latest)
[![Build Status](https://travis-ci.org/scikit-signal/tftb.svg)](https://travis-ci.org/scikit-signal/tftb)

# tftb

tftb (Time-frequency toolbox) is a Python module for time-frequency analysis and visualization
build with SciPy and matplotlib.

The tftb project began as a Python implementation of the TFTB toolbox developed by
François Auger, Olivier Lemoine, Paulo Gonçalvès and Patrick Flandrin. While this project and the
MATLAB implementation (henceforth referred to as TFTB) are similar in the core algorithms and the
basic code organization, the very nature of the Python programming language has motivated a very
different approach in architecture of PyTFTB (differences between the two packages have been
discussed in detail [here](https://tftb.readthedocs.io/en/latest/introduction.html#comparison-of-tftb-and-pytftb)).


## Installation

tftb requires:
    - Python (>= 3.5)
    - NumPy
    - SciPy
    - Matplotlib

Install tftb with pip as follows:
```bash
$ pip install tftb
```
